@@ -28,7 +28,7 @@ static void add_mem_graph (GTopProcViewData *d, gint pid);
 
 static void set_mem_map (GTopProcMapRow **rows, GtkWidget *mcl);
 
-static int  delete_event_handler (GtkWidget *, gpointer, GTopProcViewData *);
+static void  destroy_handler (GtkWidget *, GTopProcViewData *);
 static void auto_update_cb (GtkWidget *, GTopProcViewData *);
 static void close_cb (GtkWidget *, GTopProcViewData *);
 static void update_cb (GtkWidget *, GTopProcViewData *);
@@ -117,8 +117,8 @@ procview_details (GTopProcViewData *d, gint pid)
 			    FALSE, TRUE, GNOME_PAD_SMALL);
 
 	gtk_signal_connect
-	    (GTK_OBJECT (d->details.dwin), "delete_event",
-	     GTK_SIGNAL_FUNC (delete_event_handler), (gpointer) d);
+	    (GTK_OBJECT (d->details.dwin), "destroy",
+	     GTK_SIGNAL_FUNC (destroy_handler), (gpointer) d);
 
 	gnome_dialog_button_connect
 	    (GNOME_DIALOG (d->details.dwin), 1,
@@ -150,17 +150,11 @@ procview_details (GTopProcViewData *d, gint pid)
     display_details (d, pid);
 }
 
-static int
-delete_event_handler (GtkWidget *widget,
-		      gpointer func_data,
-		      GTopProcViewData *d)
+static void
+destroy_handler (GtkWidget *widget, GTopProcViewData *d)
 {
-    gtk_widget_destroy (d->details.dwin);
-
     d->details.dwin = d->details.icl = NULL;
     d->details.mcl = d->details.gswin = NULL;
-
-    return TRUE;
 }
 
 static void
@@ -202,7 +196,7 @@ close_cb (GtkWidget *widget, GTopProcViewData *d)
     gnome_config_set_int ("gtop/details/h", h);
     gnome_config_sync ();
 
-    delete_event_handler (widget, NULL, d);
+    gtk_widget_destroy(d->details.dwin);
 }
 
 static void
@@ -333,6 +327,7 @@ add_info (GTopProcViewData *d, gint pid)
 
 	dt->icl = gtk_clist_new (3);
 
+	gtk_widget_ensure_style(dt->icl);
 	style = gtk_style_copy (gtk_widget_get_style (dt->icl));
 	style->font = gtop_properties.procview.font;
 	gtk_widget_set_style (dt->icl, style);
@@ -343,6 +338,7 @@ add_info (GTopProcViewData *d, gint pid)
 
 	    gtk_misc_set_alignment (GTK_MISC (l), 1.0, 0.5);
 
+	    gtk_widget_ensure_style(l);
 	    style = gtk_style_copy (gtk_widget_get_style (l));
 	    style->font = gtop_properties.procview.font;
 	    gtk_widget_set_style (l, style);
@@ -598,6 +594,7 @@ gtop_details_create_mem_map (gint pid)
 
     mcl = gtk_clist_new (MAP_COLS);
 		
+    gtk_widget_ensure_style(mcl);	
     style = gtk_style_copy (gtk_widget_get_style (mcl));
     style->font = gtop_properties.procview.font;
     gtk_widget_set_style (mcl, style);
@@ -611,6 +608,7 @@ gtop_details_create_mem_map (gint pid)
 	else
 	    gtk_misc_set_alignment (GTK_MISC (l), 1.0, 0.5);
 
+	gtk_widget_ensure_style(l);
 	style = gtk_style_copy (gtk_widget_get_style (l));
 	style->font = gtop_properties.procview.font;
 	gtk_widget_set_style (l, style);
@@ -704,6 +702,7 @@ add_mem_map (GTopProcViewData *d, gint pid)
 
 	dt->mcl = gtk_clist_new (MAP_COLS);
 		
+	gtk_widget_ensure_style(dt->mcl);
 	style = gtk_style_copy (gtk_widget_get_style (dt->mcl));
 	style->font = gtop_properties.procview.font;
 	gtk_widget_set_style (dt->mcl, style);
@@ -717,6 +716,7 @@ add_mem_map (GTopProcViewData *d, gint pid)
 	    else
 		gtk_misc_set_alignment (GTK_MISC (l), 1.0, 0.5);
 
+	    gtk_widget_ensure_style (l);
 	    style = gtk_style_copy (gtk_widget_get_style (l));
 	    style->font = gtop_properties.procview.font;
 	    gtk_widget_set_style (l, style);
@@ -776,7 +776,7 @@ add_mem_map (GTopProcViewData *d, gint pid)
 			    GTK_SIGNAL_FUNC (drag_data_get),
 			    config_string);
 
-	gtk_drag_source_set (dt->nb, GDK_BUTTON1_MASK,
+	gtk_drag_source_set (dt->mcl, GDK_BUTTON1_MASK,
 			     gtop_target_table, 1,
 			     GDK_ACTION_COPY | GDK_ACTION_MOVE);
 
