@@ -21,7 +21,7 @@ struct _GTopFsUsageData
 	GtkWidget	*sw, *graph;
 	gchar		*graph_head;
 	gchar		*graph_tail;
-	gulong		value_total;
+	gint64		value_total;
 };
 
 extern GnomePropertyDescriptor FsUsageProperty_Descriptor;
