@@ -558,3 +558,20 @@ global_properties_save (GnomePropertyObject *object)
 		("gtop/global/show_toolbar",
 		 gtop_properties.global.show_toolbar);
 }
+
+void
+gtop_check_old_config (void)
+{
+    int config_version;
+
+    config_version = gnome_config_get_int ("gtop/config/config_version");
+    if (config_version < 2) {
+	/* We have an old config file. */
+
+	gnome_config_clean_file ("gtop");
+
+	gnome_config_set_int ("gtop/config/config_version", 2);
+
+	gnome_config_sync ();
+    }
+}
