@@ -9,11 +9,11 @@ GdkColor graph_default_colors [GRAPH_DEFAULT_COLORS] = {
 };
 
 static const gchar *default_fonts [5] = {
-	"-*-courier-medium-r-*-*-10-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-12-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-14-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-18-*-*-*-m-*-*-*",
-	"-*-courier-medium-r-*-*-24-*-*-*-m-*-*-*"
+	"-*-*-medium-r-*-*-10-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-12-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-14-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-18-*-*-*-*-*-*-*",
+	"-*-*-medium-r-*-*-24-*-*-*-*-*-*-*"
 };
 
 static void	graph_expose (GtkWidget *, GdkEventExpose *, Graph *);
@@ -128,7 +128,7 @@ graph_unrealize (GtkWidget *widget, Graph *g)
 Graph *
 graph_new (GtkWidget *da, GraphDataFunc d_fn, gpointer user_data)
 {
-	Graph *g = g_new (Graph, 1);
+	Graph *g = g_new0 (Graph, 1);
 
 	memset (g, 0, sizeof (Graph));
 
@@ -228,7 +228,7 @@ graph_process_data (Graph *g)
 		g->colors_allocated = 1;
 	}
 
-	tgcs = g_new (GdkGC *, g->n);
+	tgcs = g_new0 (GdkGC *, g->n);
 	for (i = 0; i < g->n; i++) {
 		tgcs [i] = gdk_gc_new (g->da->window);
 
@@ -755,13 +755,13 @@ graph_properties_load (GnomePropertyObject *object)
 	gtop_properties.graph.font_name = gnome_config_get_string (name);
 
 	if (gtop_properties.graph.font_name)
-		gtop_properties.graph.font = gdk_font_load
+		gtop_properties.graph.font = gdk_fontset_load
 			(gtop_properties.graph.font_name);
 
 	if (!gtop_properties.graph.font) {
 		g_free (gtop_properties.graph.font_name);
 		gtop_properties.graph.font_name = g_strdup (default_font);
-		gtop_properties.graph.font = gdk_font_load
+		gtop_properties.graph.font = gdk_fontset_load
 			(gtop_properties.graph.font_name);
 	}
 
