@@ -44,7 +44,7 @@ struct _Graph {
 	GraphDataFunc data_fn;
 };
 
-void          graph_destroy (GtkWidget *);
+void          graph_destroy (Graph *);
 Graph       * graph_new (GtkWidget *, GraphDataFunc, gpointer);
 GtkWidget   * graph_widget (Graph *);
 void          graph_update (Graph *);
