@@ -18,6 +18,8 @@ BEGIN_GNOME_DECLS
 #define GTOP_PAGE_CLASS(klass)	GTK_CHECK_CLASS_CAST (klass, gtop_page_get_type (), GTopPageClass)
 #define IS_GTOP_PAGE(obj)	GTK_CHECK_TYPE (obj, gtop_page_get_type ())
 
+typedef GtkWidget *		(*GTopGenericFunc)(gpointer);
+
 typedef struct _GTopPage	GTopPage;
 typedef struct _GTopPageClass	GTopPageClass;
 
@@ -27,7 +29,8 @@ enum _GTopPageType
 {
 	GTOP_PAGE_PROCVIEW = 0,
 	GTOP_PAGE_MEMUSAGE,
-	GTOP_PAGE_FSUSAGE
+	GTOP_PAGE_FSUSAGE,
+	GTOP_PAGE_GENERIC
 };
 
 struct _GTopPage
@@ -36,6 +39,10 @@ struct _GTopPage
 
 	GTopPageType type;
 	gint subtype;
+
+	GTopGenericFunc generic_func;
+	gchar *config_string, *label;
+	gpointer generic_data;
 };
 
 struct _GTopPageClass
@@ -43,6 +50,8 @@ struct _GTopPageClass
 	GnomeMDIChildClass parent_class;
 };
 
+GTopPage *gtop_generic_page_new (GTopGenericFunc, const gchar *,
+				 const gchar *, gpointer);
 GTopPage *gtop_page_new (GTopPageType type, gint subtype);
 GnomeMDIChild *gtop_page_create_from_config (const gchar *);
 
