@@ -16,6 +16,7 @@ static void	gtop_procview_init		(GTopProcView *);
 static void	gtop_procview_destroy		(GtkObject *);
 static void	gtop_procview_map		(GtkWidget *);
 static void	gtop_procview_unmap		(GtkWidget *);
+static void	gtop_procview_unrealize		(GtkWidget *);
 static void	gtop_procview_type_set		(GTopProcView *, gint);
 static void	gtop_procview_menu_cb		(GtkWidget *, gpointer);
 static void	gtop_procview_flags_cb		(GtkWidget *, gpointer);
@@ -148,6 +149,21 @@ gtop_procview_unmap (GtkWidget *obj)
 		(* GTK_WIDGET_CLASS (parent_class)->unmap) (obj);
 }
 
+static void
+gtop_procview_unrealize (GtkWidget *obj)
+{
+	GTopProcView *procview = GTOP_PROCVIEW (obj);
+
+	if (procview->run_tag != -1) {
+		gtk_timeout_remove (procview->run_tag);
+
+		procview->run_tag = -1;
+	}
+
+	if (GTK_WIDGET_CLASS (parent_class)->unrealize)
+		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (obj);
+}
+
 static void
 gtop_procview_destroy (GtkObject *obj)
 {
@@ -216,6 +232,9 @@ gtop_procview_flags_cb (GtkWidget *widget, gpointer data)
 		d->proc_selection_flags |= (1 << GPOINTER_TO_INT (uidata));
 	else
 		d->proc_selection_flags &= ~(1 << GPOINTER_TO_INT (uidata));
+
+	if (GTK_WIDGET_REALIZED (procview))
+		procview_update (&procview->data);
 }
 
 gchar *
@@ -248,6 +267,9 @@ gtop_procview_type_set (GTopProcView *procview, gint ftype)
 			(GNOME_MDI_CHILD (procview->page), label);
 
 	procview_type_set (&procview->data, ftype);
+
+	if (GTK_WIDGET_REALIZED (procview))
+		procview_update (&procview->data);
 }
 
 static void
@@ -266,6 +288,7 @@ gtop_procview_class_init (GTopProcViewClass *class)
 
 	widget_class->map = gtop_procview_map;
 	widget_class->unmap = gtop_procview_unmap;
+	widget_class->unrealize = gtop_procview_unrealize;
 
 	widget_class->size_request = gtop_procview_size_request;
 	widget_class->size_allocate = gtop_procview_size_allocate;
