@@ -44,7 +44,7 @@ guint		gtop_procview_get_type	(void);
 
 extern GnomeMDI *mdi;
 
-extern gchar *gtop_procview_type_labels[];
+extern GnomeUIInfo gtop_procview_radio_items [];
 
 END_GNOME_DECLS
 
