@@ -217,6 +217,10 @@ main (int argc, char *argv[])
 
 	poptFreeContext (ctx);
 
+	/* Check whether we have an old config file. */
+
+	gtop_check_old_config ();
+
 	/* Initialize LibGTop. */
 
 	gtop_init_libgtop ();
