@@ -250,7 +250,7 @@ view_changed_cb (GnomeMDI *mdi, GtkWidget *old_view)
 static void
 app_destroy_cb (GnomeApp *app, GTopStatusBarData *d)
 {
-	gtop_statusbar_destroy (d);
+	/* empty */
 }
 
 static void
@@ -258,14 +258,43 @@ drag_data_received (GtkWidget *widget, GdkDragContext *context,
 		    gint x, gint y, GtkSelectionData *data,
 		    guint info, guint32 time)
 {
-    if (data->format == 1) {
-	    GnomeMDIChild *child = gtop_page_create_from_config (data->data);
+	if (data->format == 1) {
+		GnomeMDIChild *child = gtop_page_create_from_config (data->data);
 		
-	    gnome_mdi_add_child (mdi, child);
-	    gnome_mdi_add_view (mdi, child);
-    }
+		gnome_mdi_add_child (mdi, child);
+		gnome_mdi_add_view (mdi, child);
+	}
 
-    gtk_drag_finish (context, FALSE, FALSE, time);
+	gtk_drag_finish (context, FALSE, FALSE, time);
+}
+
+static gint
+app_created_idle (GnomeApp *app)
+{
+	GnomeUIInfo *mb = gnome_mdi_get_menubar_info (app);
+
+	while (gtk_events_pending ()) { gtk_main_iteration_do (FALSE); gdk_flush (); }
+
+	/* set menu/toolbar visibility */
+	if (!gtop_properties.global.show_menubar) {
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+						(((GnomeUIInfo *)mb [1].moreinfo) [0].widget),
+						1);
+		gtop_properties.global.show_menubar = 0;
+	}
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+					(((GnomeUIInfo *)mb [1].moreinfo) [0].widget),
+					gtop_properties.global.show_menubar);
+	if (!gtop_properties.global.show_toolbar) {
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+						(((GnomeUIInfo *)mb [1].moreinfo) [1].widget),
+						1);
+		gtop_properties.global.show_toolbar = 0;
+	}
+	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
+					(((GnomeUIInfo *)mb [1].moreinfo) [1].widget),
+					gtop_properties.global.show_toolbar);
+	return FALSE;
 }
 
 static void
@@ -280,6 +309,8 @@ app_created_cb (GnomeMDI *mdi, GnomeApp *app)
 	gnome_app_set_statusbar_custom (app, d->container, d->status_bar);
         gnome_app_install_menu_hints (app, gnome_mdi_get_menubar_info (app));
 
+	gtk_idle_add ((GtkFunction) app_created_idle, (gpointer) app);
+
 	gtk_signal_connect (GTK_OBJECT (app), "drag_data_received",
 			    GTK_SIGNAL_FUNC (drag_data_received), NULL);
 
