@@ -19,9 +19,8 @@
 #include <gtop-graph.h>
 #include <process-details.h>
 
-static int
-delete_event_handler		(GtkWidget *widget, gpointer func_data,
-				 GTopProcessDetails *d);
+static void
+destroy_handler		(GtkWidget *widget, GTopProcessDetails *d);
 static void
 update_cb			(GtkWidget *widget, GTopProcessDetails *d);
 
@@ -162,8 +161,8 @@ gtop_process_details (gint pid)
     update_cb (NULL, d);
 
     gtk_signal_connect
-	(GTK_OBJECT (d->dialog), "delete_event",
-	 GTK_SIGNAL_FUNC (delete_event_handler), (gpointer) d);
+	(GTK_OBJECT (d->dialog), "destroy",
+	 GTK_SIGNAL_FUNC (destroy_handler), (gpointer) d);
 
     gnome_dialog_button_connect
 	(GNOME_DIALOG (d->dialog), 0,
@@ -178,20 +177,16 @@ gtop_process_details (gint pid)
     g_free (title);
 }
 
-static int
-delete_event_handler (GtkWidget *widget, gpointer func_data,
-		      GTopProcessDetails *d)
+static void
+destroy_handler (GtkWidget *widget, GTopProcessDetails *d)
 {
     if (d->timeout_id) {
 	gtk_timeout_remove (d->timeout_id);
 	d->timeout_id = 0;
     }
 
-    gtk_widget_destroy (d->dialog);
     d->dialog = NULL;
     g_free (d);
-
-    return TRUE;
 }
 
 static void
@@ -219,7 +214,7 @@ close_cb (GtkWidget *widget, GTopProcessDetails *d)
     gnome_config_set_int ("gtop/process_details/h", h);
     gnome_config_sync ();
 
-    delete_event_handler (widget, NULL, d);
+    gtk_widget_destroy(d->dialog);
 }
 
 static gint
@@ -299,6 +294,7 @@ fill_clist (GtkCList *list, const gint widths [],
     gtk_clist_freeze (list);
     gtk_clist_clear (list);
 
+    gtk_widget_ensure_style(GTK_WIDGET(list));
     font = gtk_widget_get_style (GTK_WIDGET(list))->font;
     cw = gdk_char_width (font, 'M');
 
@@ -360,8 +356,9 @@ process_state_create (GTopProcessDetails *d)
     l = gtk_label_new (_("Process State:"));
     gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
     gtk_misc_set_padding (GTK_MISC (l), GNOME_PAD_SMALL, 0);
+    gtk_widget_ensure_style(l);
 
-    style = gtk_widget_get_style (l);
+    style = gtk_style_copy(gtk_widget_get_style (l));
     style->font = gtop_properties.procview.font;
     gtk_widget_set_style (l, style);
 
@@ -424,8 +421,9 @@ process_args_create (GTopProcessDetails *d)
     l = gtk_label_new (_("Command Line:"));
     gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
     gtk_misc_set_padding (GTK_MISC (l), GNOME_PAD_SMALL, 0);
+    gtk_widget_ensure_style(l);
 
-    style = gtk_widget_get_style (l);
+    style = gtk_style_copy(gtk_widget_get_style (l));
     style->font = gtop_properties.procview.font;
     gtk_widget_set_style (l, style);
 
@@ -528,8 +526,9 @@ process_credentials_create (GTopProcessDetails *d)
     l = gtk_label_new (_("Process Credentials:"));
     gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
     gtk_misc_set_padding (GTK_MISC (l), GNOME_PAD_SMALL, 0);
+    gtk_widget_ensure_style(l);
 
-    style = gtk_widget_get_style (l);
+    style = gtk_style_copy(gtk_widget_get_style (l));
     style->font = gtop_properties.procview.font;
     gtk_widget_set_style (l, style);
 
