@@ -1025,10 +1025,10 @@ procview_update (GTopProcViewData *d)
 	gint i, j, n=0;
 	gint p_cl_sum;
 
-	gint p_current_time;
 	time_t p_time;
-	float p_elapsed_time;
-	unsigned long p_total_time;
+	double p_elapsed_time;
+	double p_total_time;
+	double p_current_time;
 
 	p_cl_sum = gtop_properties.procview.details_flags &
 		(1 << GTOP_DETAILS_CUMULATIVE_TIMINGS);
@@ -1143,13 +1143,12 @@ procview_update (GTopProcViewData *d)
 
 		p->frequency = proctime.frequency ? proctime.frequency : 1000000;
 
-		p->utime  = ((unsigned long) (proctime.utime * 100) / p->frequency);
-		p->stime  = ((unsigned long) (proctime.stime * 100) / p->frequency);
-		p->cutime = ((unsigned long) (proctime.cutime * 100) / p->frequency);
-		p->cstime = ((unsigned long) (proctime.cstime * 100) / p->frequency);
+		p->utime  = (unsigned long) proctime.utime;
+		p->stime  = (unsigned long) proctime.stime;
+		p->cutime = (unsigned long) proctime.cutime;
+		p->cstime = (unsigned long) proctime.cstime;
 
-		p->start_time =
-			((unsigned long) (proctime.start_time * 100) / p->frequency);
+		p->start_time = (unsigned long) proctime.start_time;
 
 		/* compute some own fields for proc_data */
 		/* PCPU */
@@ -1178,11 +1177,10 @@ procview_update (GTopProcViewData *d)
 		}
 
 		if (first)
-			p_elapsed_time = (p_current_time*100 -
-					  p->start_time)/p->frequency;
+			p_elapsed_time = p_current_time - ((double) p->start_time / p->frequency);
 
 		data->pcpu = (p_elapsed_time > 0.001) ? (unsigned int)
-			((float) (p_total_time * 10) / p_elapsed_time) : 0;
+			((p_total_time * 1000.0 / (double) p->frequency) / p_elapsed_time) : 0;
 
 		if (data->pcpu > 999)
 			data->pcpu = 999;
