@@ -92,6 +92,9 @@ struct _GTopGlobalProperties
 	gint save_session;
 	GnomeMDIMode mdi_mode;
 	glong update_times [UPDATE_FIELDS];
+
+	gint show_menubar;
+	gint show_toolbar;
 };
 
 struct _GTopMemUsageProperties
