@@ -4,6 +4,7 @@
 #include <gtop-fsusage.h>
 #include <gtop-memusage.h>
 #include <gtop-procview.h>
+#include <gtop-procbar.h>
 
 #include <netdb.h>
 
@@ -191,13 +192,13 @@ summary_cpu (GTopSummaryData *d)
 		return TRUE;
 
 	proc_read_cpu (d->summary_info);
-	gnome_proc_bar_set_values
-		(GNOME_PROC_BAR (d->summary_cpu), d->summary_info->cpu);
+	gtop_proc_bar_set_values
+		(GTOP_PROC_BAR (d->summary_cpu), d->summary_info->cpu);
 
 #ifdef HAVE_LIBGTOP_SMP
 	for (i = 0; i < ncpu; i++)
-		gnome_proc_bar_set_values
-			(GNOME_PROC_BAR (d->summary_xcpu [i]),
+		gtop_proc_bar_set_values
+			(GTOP_PROC_BAR (d->summary_xcpu [i]),
 			 d->summary_info->xcpu [i]);
 #endif
 		
@@ -211,8 +212,8 @@ summary_mem (GTopSummaryData *d)
 		return TRUE;
 
 	proc_read_mem (d->summary_info);
-	gnome_proc_bar_set_values
-		(GNOME_PROC_BAR (d->summary_mem), d->summary_info->mem);
+	gtop_proc_bar_set_values
+		(GTOP_PROC_BAR (d->summary_mem), d->summary_info->mem);
 
 	return TRUE;
 }
@@ -224,8 +225,8 @@ summary_swap (GTopSummaryData *d)
 		return TRUE;
 
 	proc_read_mem (d->summary_info);
-	gnome_proc_bar_set_values
-		(GNOME_PROC_BAR (d->summary_swap), d->summary_info->swap);
+	gtop_proc_bar_set_values
+		(GTOP_PROC_BAR (d->summary_swap), d->summary_info->swap);
 
 	return TRUE;
 }
@@ -237,8 +238,8 @@ summary_load (GTopSummaryData *d)
 		return TRUE;
 
 	proc_read_load (d->summary_info);
-	gnome_proc_bar_set_values
-		(GNOME_PROC_BAR (d->summary_load), d->summary_info->load);
+	gtop_proc_bar_set_values
+		(GTOP_PROC_BAR (d->summary_load), d->summary_info->load);
 
 	return TRUE;
 }
@@ -251,25 +252,25 @@ summary_create (GTopSummaryData *d)
 
 	proc_read_mem (d->summary_info);
 
-	d->summary_cpu = gnome_proc_bar_new
+	d->summary_cpu = gtop_proc_bar_new
 		(d->xpm_cpu, PROC_CPU_SIZE-1,
 		 gtop_properties.summary_colors.cpu, summary_cpu);
 
-	d->summary_mem = gnome_proc_bar_new
+	d->summary_mem = gtop_proc_bar_new
 		(d->xpm_mem, PROC_MEM_SIZE-2,
 		 gtop_properties.summary_colors.mem, summary_mem);
 
-	d->summary_swap = gnome_proc_bar_new
+	d->summary_swap = gtop_proc_bar_new
 		(d->xpm_swap, PROC_SWAP_SIZE-1,
 		 gtop_properties.summary_colors.swap, summary_swap);
 
-	d->summary_load = gnome_proc_bar_new
+	d->summary_load = gtop_proc_bar_new
 		(d->xpm_load, PROC_LOAD_SIZE-1,
 		 gtop_properties.summary_colors.load, summary_load);
 
 #ifdef HAVE_LIBGTOP_SMP
 	for (i = 0; i < ncpu; i++)
-		d->summary_xcpu [i] = gnome_proc_bar_new
+		d->summary_xcpu [i] = gtop_proc_bar_new
 			(d->xpm_xcpu [i], PROC_CPU_SIZE-1,
 			 gtop_properties.summary_colors.cpu, NULL);
 #endif
@@ -337,89 +338,89 @@ summary_update (GTopSummaryData *d)
 
 
     if (SUMMARY_GRAPH_BIT (GRAPH_CPU))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_cpu),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_cpu),
 			 gtop_properties.global.update_times [GTOP_UPDATE_CPU],
 			 d);
 	else
-		gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_cpu));
+		gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_cpu));
 
 #ifdef HAVE_LIBGTOP_SMP
     if (SUMMARY_GRAPH_BIT (GRAPH_XCPU)) {
 		if (d->summary_xcpu [0])
-			gnome_proc_bar_start
-				(GNOME_PROC_BAR (d->summary_xcpu [0]),
+			gtop_proc_bar_start
+				(GTOP_PROC_BAR (d->summary_xcpu [0]),
 				 gtop_properties.global.update_times
 				 [GTOP_UPDATE_CPU], d);
 	} else {
 		if (d->summary_xcpu [0])
-			gnome_proc_bar_stop
-				(GNOME_PROC_BAR (d->summary_xcpu [0]));
+			gtop_proc_bar_stop
+				(GTOP_PROC_BAR (d->summary_xcpu [0]));
 	}
 #endif
 
     if (SUMMARY_GRAPH_BIT (GRAPH_MEM))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_mem),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_mem),
 			 gtop_properties.global.update_times [GTOP_UPDATE_MEM],
 			 d);
 	else
-		gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_mem));
+		gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_mem));
 
 	config_has_swap = (d->summary_info->swap [PROC_SWAP_TOTAL]) &&
 	SUMMARY_GRAPH_BIT (GRAPH_SWAP);
 
 	if (config_has_swap)
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_swap),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_swap),
 			 gtop_properties.global.update_times [GTOP_UPDATE_MEM],
 			 d);
 	else
-		gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_swap));
+		gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_swap));
 
     if (SUMMARY_GRAPH_BIT (GRAPH_LOAD))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_load),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_load),
 			 gtop_properties.global.update_times [GTOP_UPDATE_LOAD],
 			 d);
 	else
-		gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_load));
+		gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_load));
 }
 
 void
 gtop_summary_map (GTopSummaryData *d)
 {
     if (SUMMARY_GRAPH_BIT (GRAPH_CPU))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_cpu),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_cpu),
 			 gtop_properties.global.update_times [GTOP_UPDATE_CPU],
 			 d);
 
 #ifdef LIBGTOP_HAVE_SMP
     if (SUMMARY_GRAPH_BIT (GRAPH_XCPU)) {
 		if (d->summary_xcpu [0])
-			gnome_proc_bar_start
-				(GNOME_PROC_BAR (d->summary_xcpu [0]),
+			gtop_proc_bar_start
+				(GTOP_PROC_BAR (d->summary_xcpu [0]),
 				 gtop_properties.global.update_times
 				 [GTOP_UPDATE_CPU], d);
 	}
 #endif
 
     if (SUMMARY_GRAPH_BIT (GRAPH_MEM))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_mem),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_mem),
 			 gtop_properties.global.update_times [GTOP_UPDATE_MEM],
 			 d);
 
     if (SUMMARY_GRAPH_BIT (GRAPH_SWAP))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_swap),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_swap),
 			 gtop_properties.global.update_times [GTOP_UPDATE_MEM],
 			 d);
 
     if (SUMMARY_GRAPH_BIT (GRAPH_LOAD))
-		gnome_proc_bar_start
-			(GNOME_PROC_BAR (d->summary_load),
+		gtop_proc_bar_start
+			(GTOP_PROC_BAR (d->summary_load),
 			 gtop_properties.global.update_times [GTOP_UPDATE_LOAD],
 			 d);
 }
@@ -427,18 +428,18 @@ gtop_summary_map (GTopSummaryData *d)
 void
 gtop_summary_unmap (GTopSummaryData *d)
 {
-	gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_cpu));
+	gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_cpu));
 
 #ifdef LIBGTOP_HAVE_SMP
 	if (d->summary_xcpu [0])
-		gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_xcpu [0]));
+		gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_xcpu [0]));
 #endif
 
-	gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_mem));
+	gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_mem));
 
-	gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_swap));
+	gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_swap));
 
-	gnome_proc_bar_stop (GNOME_PROC_BAR (d->summary_load));
+	gtop_proc_bar_stop (GTOP_PROC_BAR (d->summary_load));
 }
 
 static void
@@ -1296,8 +1297,8 @@ summary_colors_properties_update (GnomePropertyObject *object)
 
 		if (d->summary_cpu && SUMMARY_GRAPH_BIT (GRAPH_CPU) &&
 		    GTK_WIDGET_REALIZED (d->summary_cpu))
-			gnome_proc_bar_update
-				(GNOME_PROC_BAR (d->summary_cpu),
+			gtop_proc_bar_update
+				(GTOP_PROC_BAR (d->summary_cpu),
 				 gtop_properties.summary_colors.cpu);
 
 #ifdef HAVE_LIBGTOP_SMP
@@ -1305,27 +1306,27 @@ summary_colors_properties_update (GnomePropertyObject *object)
 			if (d->summary_xcpu [i] &&
 			    SUMMARY_GRAPH_BIT (GRAPH_XCPU) &&
 			    GTK_WIDGET_REALIZED (d->summary_xcpu [i]))
-				gnome_proc_bar_update
-					(GNOME_PROC_BAR (d->summary_xcpu [i]),
+				gtop_proc_bar_update
+					(GTOP_PROC_BAR (d->summary_xcpu [i]),
 					 gtop_properties.summary_colors.cpu);
 #endif
 
 		if (d->summary_mem && SUMMARY_GRAPH_BIT (GRAPH_MEM) &&
 		    GTK_WIDGET_REALIZED (d->summary_mem))
-			gnome_proc_bar_update
-				(GNOME_PROC_BAR (d->summary_mem),
+			gtop_proc_bar_update
+				(GTOP_PROC_BAR (d->summary_mem),
 				 gtop_properties.summary_colors.mem);
 
 		if (d->summary_swap && SUMMARY_GRAPH_BIT (GRAPH_SWAP) &&
 		    GTK_WIDGET_REALIZED (d->summary_swap))
-			gnome_proc_bar_update
-				(GNOME_PROC_BAR (d->summary_swap),
+			gtop_proc_bar_update
+				(GTOP_PROC_BAR (d->summary_swap),
 				 gtop_properties.summary_colors.swap);
 
 		if (d->summary_load && SUMMARY_GRAPH_BIT (GRAPH_LOAD) &&
 		    GTK_WIDGET_REALIZED (d->summary_load))
-			gnome_proc_bar_update
-				(GNOME_PROC_BAR (d->summary_load),
+			gtop_proc_bar_update
+				(GTOP_PROC_BAR (d->summary_load),
 				 gtop_properties.summary_colors.load);
 	}
 }
